==> rdc_flutter_sdk-0.0.1.tar.gz: example/lib/screens/login_success/components/body.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shop_app/components/default_button.dart';
import 'package:shop_app/screens/home/home_screen.dart';
import 'package:shop_app/size_config.dart';

class Body extends StatelessWidget {
  // mark:RabbitDataInstance
  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');

  @override
  Widget build(BuildContext context) {
    rabbitData.setUserInfo('1ee7e58d-6b0c-40a9-b722-aeeed41ba270',
        'aeeed41ba270-1ee7e58d-6b0c-40a9-b722');
    rabbitData.addEvent(
        eventName: 'login',
        eventValue: 'success',
        dataLayer: {'email': 'pti@manaosoftware.com'});
    return Column(
      children: [
        SizedBox(height: SizeConfig.screenHeight * 0.04),
        Image.asset(
          "assets/images/success.png",
          height: SizeConfig.screenHeight * 0.4, //40%
        ),
        SizedBox(height: SizeConfig.screenHeight * 0.08),
        Text(
          "Login Success",
          style: TextStyle(
            fontSize: getProportionateScreenWidth(30),
            fontWeight: FontWeight.bold,
            color: Colors.black,
          ),
        ),
        Spacer(),
        SizedBox(
          width: SizeConfig.screenWidth * 0.6,
          child: DefaultButton(
            text: "Back to home",
            press: () {
              Navigator.pushNamed(context, HomeScreen.routeName);
            },
          ),
        ),
        Spacer(),
      ],
    );
  }
}

==> rdc_flutter_sdk-0.0.4.tar.gz: example/lib/screens/login_success/components/body.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shop_app/components/default_button.dart';
import 'package:shop_app/screens/home/home_screen.dart';
import 'package:shop_app/size_config.dart';

class Body extends StatelessWidget {
  // mark:RabbitDataInstance
  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');

  @override
  Widget build(BuildContext context) {
    var addUser = Future.wait([
      rabbitData.setMemberId('1ee7e58d-6b0c-40a9-b722-aeeed41ba270'),
      rabbitData.setSsoId('aeeed41ba270-1ee7e58d-6b0c-40a9-b722')
    ]);
    addUser.then((value) {
      rabbitData.addEvent(
          eventName: 'login',
          eventValue: 'success',
          dataLayer: {'email': 'rabbit@mail.com'});
    });
    return Column(
      children: [
        SizedBox(height: SizeConfig.screenHeight * 0.04),
        Image.asset(
          "assets/images/success.png",
          height: SizeConfig.screenHeight * 0.4, //40%
        ),
        SizedBox(height: SizeConfig.screenHeight * 0.08),
        Text(
          "Login Success",
          style: TextStyle(
            fontSize: getProportionateScreenWidth(30),
            fontWeight: FontWeight.bold,
            color: Colors.black,
          ),
        ),
        Spacer(),
        SizedBox(
          width: SizeConfig.screenWidth * 0.6,
          child: DefaultButton(
            text: "Back to home",
            press: () {
              Navigator.pushNamed(context, HomeScreen.routeName);
            },
          ),
        ),
        Spacer(),
      ],
    );
  }
}
